#[non_exhaustive]pub enum SlipError {
Io(Error),
UnexpectedEndOfFrame,
IncompleteEscape,
InvalidEscape(u8),
MissingFrame,
MultipleFrames(usize),
}Expand description
Error type for SLIP encoding and decoding operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(Error)
Wrapper around std::io::Error originating from the underlying reader or writer.
UnexpectedEndOfFrame
Encountered bytes that were not terminated by an END delimiter.
IncompleteEscape
Encountered an ESC byte at the end of a stream without a following escape code.
InvalidEscape(u8)
Encountered an invalid escape sequence while decoding.
MissingFrame
No complete SLIP frame was present in the input while one was expected.
MultipleFrames(usize)
More frames than expected were present in the input.