pub struct MutProxy<'a, B, V>{ /* private fields */ }Expand description
A proxy object for iterating over mutable slices.
For technical reasons (mostly alignment and padding), it’s not possible to return a simple reference. This type is returned instead and it can be used to both read and write the vectors a slice is turned into.
Note that the data are written in the destructor. Usually, this should not matter, but if you
forget, the changes will be lost (this is meant as a warning, not as a way to
implement poor-man’s transactions).