FrameRemainder

Struct FrameRemainder 

pub struct FrameRemainder {
    pub decoded: Vec<u8>,
    pub escape_pending: bool,
}
Captures decoded bytes that were buffered when a stream ended without a terminating END byte.

Fields

decoded: Vec<u8>

Decoded payload bytes collected before the unexpected end of stream.

escape_pending: bool

true if the decoder ended while waiting for the second byte of an escape sequence.

Implementations

Source

impl FrameRemainder

pub fn len(&self) -> usize

Returns the number of decoded bytes that were buffered.

pub fn is_empty(&self) -> bool

Returns true when there is no buffered payload and no pending escape sequence.