pub struct NatsConnection { /* private fields */ }Expand description
NATS JetStream KV connection.
Implementations
Sourceimpl NatsConnection
impl NatsConnection
pub fn new(config: NatsConnectionConfig) -> Self
Sourcepub fn from_client(client: Client) -> Self
pub fn from_client(client: Client) -> Self
Create a NatsConnection from an existing NATS client.
This is useful when the caller already has a NATS connection and wants to reuse it for KV stores instead of creating a new connection.