pub fn encode_iter<I>(input: I) -> Vec<u8> ⓘwhere
I: IntoIterator<Item = u8>,Expand description
Encode an arbitrary iterator of bytes as a SLIP frame and return the encoded data.
This helper is generic over any iterator to make it easy to encode common Rust collections.